@@ -9,7 +9,7 @@
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
 
-#include "/cygdrive/e/cyg_pub/devel/octave/octave-4.0.0-3.i686/src/octave-4.0.0/libgui/src/history-dock-widget.h"
+#include "/cygdrive/e/cyg_pub/devel/octave/octave-4.0.1-1.x86_64/src/octave-4.0.1/libgui/src/history-dock-widget.h"
 #if !defined(Q_MOC_OUTPUT_REVISION)
 #error "The header file 'history-dock-widget.h' doesn't include <QObject>."
 #elif Q_MOC_OUTPUT_REVISION != 63
@@ -25,7 +25,7 @@ static const uint qt_meta_data_history_dock_widget[] = {
        6,       // revision
        0,       // classname
        0,    0, // classinfo
-      16,   14, // methods
+      17,   14, // methods
        0,    0, // properties
        0,    0, // enums/sets
        0,    0, // constructors
@@ -51,6 +51,7 @@ static const uint qt_meta_data_history_dock_widget[] = {
      436,   20,   20,   20, 0x08,
      452,   20,   20,   20, 0x08,
      469,   20,   20,   20, 0x08,
+     489,  481,   20,   20, 0x08,
 
        0        // eod
 };
@@ -69,7 +70,8 @@ static const char qt_meta_stringdata_history_dock_widget[] = {
     "handle_contextmenu_evaluate(bool)\0"
     "handle_contextmenu_create_script(bool)\0"
     "pos\0ctxMenu(QPoint)\0copyClipboard()\0"
-    "pasteClipboard()\0selectAll()\0"
+    "pasteClipboard()\0selectAll()\0visible\0"
+    "handle_visibility(bool)\0"
 };
 
 void history_dock_widget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
@@ -94,6 +96,7 @@ void history_dock_widget::qt_static_metacall(QObject *_o, QMetaObject::Call _c,
         case 13: _t->copyClipboard(); break;
         case 14: _t->pasteClipboard(); break;
         case 15: _t->selectAll(); break;
+        case 16: _t->handle_visibility((*reinterpret_cast< bool(*)>(_a[1]))); break;
         default: ;
         }
     }
@@ -131,9 +134,9 @@ int history_dock_widget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
     if (_id < 0)
         return _id;
     if (_c == QMetaObject::InvokeMetaMethod) {
-        if (_id < 16)
+        if (_id < 17)
             qt_static_metacall(this, _c, _id, _a);
-        _id -= 16;
+        _id -= 17;
     }
     return _id;
 }
