@@ -9,7 +9,7 @@
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
 
-#include "/cygdrive/e/cyg_pub/devel/octave/octave-4.0.0-3.i686/src/octave-4.0.0/libgui/src/main-window.h"
+#include "/cygdrive/e/cyg_pub/devel/octave/octave-4.0.1-1.x86_64/src/octave-4.0.1/libgui/src/main-window.h"
 #if !defined(Q_MOC_OUTPUT_REVISION)
 #error "The header file 'main-window.h' doesn't include <QObject>."
 #elif Q_MOC_OUTPUT_REVISION != 63
